#------------------------------------------
#--- Author: Aniruddha Mysore for Guatam Prakash
#--- Modified by Gautam Prakash then on
#--- Date: 29th May 2017
#--- Version: 1.2
#--- Python Ver: 2.7
#--- Publish to mqtt relay topic whenever water in tank goes down
#------------------------------------------

import sqlite3
import paho.mqtt.client as mqtt
import threading

# MQTT Settings 
MQTT_Broker = "localhost"
MQTT_Port = 1883
MQTT_Topic = "relay/#"
Keep_Alive_Interval = 45

# SQLITE settings 
DB_Name = "IoT.db"
Table = "DHT22_Temperature_Data"

# Threshold to check for
Threshold_Capacity = 0.2

# Sensors to monitor
#Sensors = ["Level_Sump","Level_Sump","Level_Top"]
Sensors = ["Level_Tank"]

# Full capacity for each Sensor
Capacity = {Sensors[0] : 100
        #{Sensors[0] : 4500,
	#Sensors[1] : 400,
	#Sensors[2] : 350
         }		 

# Relay values to broadcast for each Sensor in case capacity is less than Threshold_Capacity
PumpOnRelay = {
        Sensors[0] : 1,
	#Sensors[1] : 2,
	#Sensors[2] : 2
        }
	
PumpOffRelay = {
        Sensors[0] : 0,
	#Sensors[1] : 3,
	#Sensors[2] : 3
        }	

#====================================================

def on_connect(client, userdata, rc):
	if rc != 0:
		pass
		print "Unable to connect to MQTT Broker..."
	else:
		print "Connected with MQTT Broker: " + str(MQTT_Broker)

def on_publish(client, userdata, mid):
	pass
		
def on_disconnect(client, userdata, rc):
	if rc !=0:
		pass
		
mqttc = mqtt.Client()
mqttc.on_connect = on_connect
mqttc.on_disconnect = on_disconnect
mqttc.on_publish = on_publish
mqttc.connect(MQTT_Broker, int(MQTT_Port), int(Keep_Alive_Interval))		

		
def publish_To_Topic(topic, message):
	mqttc.publish(topic,message)
	print ("Published: " + str(message) + " " + "on MQTT Topic: " + str(topic))
	print ""


#====================================================

def publish_To_Relay():
	#Connect or Create DB File
	conn = sqlite3.connect(DB_Name)
	curs = conn.cursor()
	threading.Timer(3.0, publish_To_Relay).start()
	for sensor in Sensors:
		query = "SELECT Lits FROM "+Table+" WHERE SensorID = '"+sensor+"' ORDER BY id DESC LIMIT 1;"
		curs.execute(query)
		result = curs.fetchone()
		if result is not None: 
			print sensor+" water level = "+result[0] 
						
			if sensor == Sensors[0]: 
				if float(result[0]) < Threshold_Capacity*Capacity[sensor]:
					print "Water level low. Sending Warning"
					publish_To_Topic ("relay/warning", PumpOnRelay[sensor])
				else: 
					print "Water level sufficient. No need to worry"
					publish_To_Topic ("relay/warning", PumpOffRelay[sensor])
			
			elif float(result[0]) < Threshold_Capacity*Capacity[sensor]:
				print "Water level low. Sending Pump On Signal"
				#publish_To_Topic (MQTT_Topic, PumpOnRelay[sensor])
				publish_To_Topic ("relay/pump", PumpOnRelay[sensor])
			else: 
				print "Water level sufficient. Sending Pump Off Signal"
				#publish_To_Topic (MQTT_Topic, PumpOffRelay[sensor])
				publish_To_Topic ("relay/pump", PumpOffRelay[sensor])
		else:
			print "No data found in SensorID ['"+sensor+"']"
		
	#Close DB
	curs.close()
	conn.close()

publish_To_Relay()



